@@ -15,7 +15,7 @@ try:
 except ImportError:
     from urllib.request import Request, urlopen, urlretrieve
 
-resource_file_hash = 'a018a3cdd256b5d454033601e33a5295'
+resource_file_hash = '6c01752524f79084c642e3ecc4b4fdd7'
 
 
 def export_to_json(data_dict, export_file_path):
@@ -176,19 +176,27 @@ def scan_vulnerabilities():
             return data
         else:
             print(stylize(
-                'Downloading resources to scan the packages .....', colored.fg("green")))
+                'Downloading resources to scan the packages, It may take some time to download  .....', colored.fg("green")))
             ssl._create_default_https_context = ssl._create_unverified_context
             url = 'https://pyraider-source-data.s3-us-west-2.amazonaws.com/resource.pickle'
-            urlretrieve(url, data_path)
+            try:
+                urlretrieve(url, data_path)
+            except Exception as e:
+                print(stylize('There is some error. You need to enable `https://pyraider-source-data.s3-us-west-2.amazonaws.com/` URL to download database',
+                              colored.fg("red")))
             data = pickle.load(open(data_path, 'rb'))
             print(stylize('Resource has been successfully downloaded',
                           colored.fg("green")))
             return data
     else:
-        print(stylize('Downloading latest resource database .....', colored.fg("green")))
+        print(stylize('Downloading resources to scan the packages, It may take some time to download  .....', colored.fg("green")))
         ssl._create_default_https_context = ssl._create_unverified_context
         url = 'https://pyraider-source-data.s3-us-west-2.amazonaws.com/resource.pickle'
-        urlretrieve(url, data_path)
+        try:
+            urlretrieve(url, data_path)
+        except Exception as e:
+            print(stylize('There is some error. You need to enable `https://pyraider-source-data.s3-us-west-2.amazonaws.com/` URL to download database',
+                          colored.fg("red")))
         data = pickle.load(open(data_path, 'rb'))
         print(stylize('Resource has been successfully downloaded', colored.fg("green")))
         return data
@@ -203,10 +211,14 @@ def check_latestdb():
     if resource_file_hash == hashlib.md5(open(data_path, 'rb').read()).hexdigest():
         print(stylize('Resource database is already upto date', colored.fg("green")))
     else:
-        print(stylize('Downloading latest resource database .....', colored.fg("green")))
+        print(stylize('Downloading resources to scan the packages, It may take some time to download  .....', colored.fg("green")))
         ssl._create_default_https_context = ssl._create_unverified_context
         url = 'https://pyraider-source-data.s3-us-west-2.amazonaws.com/resource.pickle'
-        urlretrieve(url, data_path)
+        try:
+            urlretrieve(url, data_path)
+        except Exception as e:
+            print(stylize('There is some error. You need to enable `https://pyraider-source-data.s3-us-west-2.amazonaws.com/` URL to download database',
+                          colored.fg("red")))
         print(stylize('Resource database has been successfully updated',
                       colored.fg("green")))
 
